#
# spec file for package ghc-mwc-probability
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name mwc-probability
Name:           ghc-%{pkg_name}
Version:        1.3.0
Release:        lp150.1.8
Summary:        Sampling function-based probability distributions
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-mwc-random-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel

%description
A simple probability distribution type, where distributions are characterized
by sampling functions.

This implementation is a thin layer over 'mwc-random', which handles RNG
state-passing automatically by using a 'PrimMonad' like 'IO' or 'ST s' under
the hood.

/Examples/

Transform a distribution's support while leaving its density structure
invariant:

> -- uniform over [0, 1] to uniform over [1, 2] > succ <$> uniform

Sequence distributions together using bind:

> -- a beta-binomial conjugate distribution > beta 1 10 >>= binomial 10

Use do-notation to build complex joint distributions from composable, local
conditionals:

> hierarchicalModel = do > [c, d, e, f] <- replicateM 4 $ uniformR (1, 10) > a
<- gamma c d > b <- gamma e f > p <- beta a b > n <- uniformR (5, 10) >
binomial n p.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Jul 21 2017 psimons@suse.com
- Update to version 1.3.0 revision 1.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.3.0 with cabal2obs.
* Sun Oct 30 2016 psimons@suse.com
- Update to version 1.2.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.1 revision 0 with cabal2obs.
